@@ -2,14 +2,14 @@
 #' 
 #' @description The function returns the product poset of two posets \code{X} and \code{Y}.
 #'
-#' @param x an S4 object of class \code{Rcpp_POSet}, see \code{\link[POSetR]{poset}} for details.
-#' @param y an S4 object of class \code{Rcpp_POSet}, see \code{\link[POSetR]{poset}} for details.
+#' @param x an S4 object of class \code{poset}, see \code{\link[POSetR]{poset}} for details.
+#' @param y an S4 object of class \code{poset}, see \code{\link[POSetR]{poset}} for details.
 #' @param sep a character object indicating the separator to be used to paste profiles names.
 #'
 #' @usage productOrder(x, y, sep = "-")
 #' @usage x \%po\% y
 #' @aliases productOrder %po%
-#' @return an S4 object of class \code{Rcpp_POSet}, see \code{\link[POSetR]{poset}} for details
+#' @return an environment of class \code{poset}, see \code{\link[POSetR]{poset}} for details
 #' @seealso \code{\link[POSetR]{poset}}
 #' @export
 #'
@@ -28,10 +28,16 @@
 
 
 productOrder <- function(x, y, sep = "-") {
-  stopifnot(class(x) == "Rcpp_POSet")
-  stopifnot(class(y) == "Rcpp_POSet")
+  stopifnot(class(x) == "poset")
+  stopifnot(class(y) == "poset")
   
-  res <- new(POSet, x$elements(), x$comparabilities(), y$elements(), y$comparabilities(), sep)
+  res <- new.env()
+  res$pointer <- new(POSet, x$pointer$elements(), x$pointer$comparabilities(), y$pointer$elements(), y$pointer$comparabilities(), sep)
+  
+  res$elements <- res$pointer$elements()
+  res$comparabilities <- res$pointer$comparabilities()
+  
+  class(res) <- "poset"
   
   return(res)
 }
